@@ -16,7 +16,6 @@ from therapy import PREFIX_LOOKUP
 logger = logging.getLogger("therapy")
 logger.setLevel(logging.DEBUG)
 
-
 # can be set to either `Dev`, `Staging`, or `Prod`
 # ONLY set when wanting to access aws instance
 AWS_ENV_VAR_NAME = "THERAPY_NORM_ENV"
@@ -81,7 +80,6 @@ class Database:
             if aws_env == AwsEnvName.DEVELOPMENT:
                 therapy_concepts_table = "therapy_concepts_nonprod"
                 therapy_metadata_table = "therapy_metadata_nonprod"
-            self.endpoint_url = ""
         else:
             if db_url:
                 self.endpoint_url = db_url
@@ -89,7 +87,8 @@ class Database:
                 self.endpoint_url = environ["THERAPY_NORM_DB_URL"]
             else:
                 self.endpoint_url = "http://localhost:8000"
-            click.echo(f"***Using Therapy Database Endpoint: {self.endpoint_url}***")
+            click.echo(f"***Using Therapy Database Endpoint: "
+                       f"{self.endpoint_url}***")
             environ["DISEASE_NORM_DB_URL"] = self.endpoint_url
 
             boto_params = {
