@@ -7,13 +7,13 @@ import json
 
 from uvicorn.config import logger
 from botocore.exceptions import ClientError
+from ga4gh.vrsatile.pydantic.vrsatile_models import TherapeuticDescriptor
 
 from therapy import SOURCES, PREFIX_LOOKUP, ITEM_TYPES, NAMESPACE_LUIS
 from therapy.database import Database
 from therapy.schemas import BaseNormalizationService, Drug, SourceMeta, MatchType, \
     ServiceMeta, HasIndication, SourcePriority, SearchService, NormalizationService, \
-    NamespacePrefix, SourceName, TherapyDescriptor, UnmergedNormalizationService, \
-    MatchesNormalized
+    NamespacePrefix, SourceName, UnmergedNormalizationService, MatchesNormalized
 
 
 NormService = TypeVar("NormService", bound=BaseNormalizationService)
@@ -386,10 +386,10 @@ class QueryHandler:
         :return: completed response object.
         """
         sources_meta = {}
-        vod = response.therapy_descriptor
+        vod = response.therapeutic_descriptor
 
         xrefs = vod.xrefs or []  # type: ignore
-        ids = [vod.therapy_id] + xrefs  # type: ignore
+        ids = [vod.therapeutic] + xrefs  # type: ignore
         for concept_id in ids:
             prefix = concept_id.split(":")[0]
             src_name = PREFIX_LOOKUP[prefix.lower()]
@@ -419,8 +419,8 @@ class QueryHandler:
         """
         vod = {
             "id": f"normalize.therapy:{quote(query.strip())}",
-            "type": "TherapyDescriptor",
-            "therapy_id": record["concept_id"],
+            "type": "TherapeuticDescriptor",
+            "therapeutic": record["concept_id"],
             "label": record.get("label"),
             "extensions": [],
         }
@@ -455,7 +455,7 @@ class QueryHandler:
                     "id": indication.disease_id,
                     "type": "DiseaseDescriptor",
                     "label": indication.disease_label,
-                    "disease_id": indication.normalized_disease_id,
+                    "disease": indication.normalized_disease_id,
                 }
                 if indication.supplemental_info:
                     ind_value_obj["extensions"] = [
@@ -486,7 +486,7 @@ class QueryHandler:
             del vod["extensions"]
 
         response.match_type = match_type
-        response.therapy_descriptor = TherapyDescriptor(**vod)  # type: ignore
+        response.therapeutic_descriptor = TherapeuticDescriptor(**vod)  # type: ignore
         response = self._add_merged_meta(response)
         return response
 
