@@ -1,12 +1,11 @@
 """This module contains data models for representing VICC therapy records."""
-from typing import List, Literal, Optional, Dict, Union, Any, Type, Set
+from typing import List, Optional, Dict, Union, Any, Type, Set
 from enum import Enum, IntEnum
 from datetime import datetime
 
-from ga4gh.vrsatile.pydantic import return_value
-from ga4gh.vrsatile.pydantic.vrs_models import CURIE
-from ga4gh.vrsatile.pydantic.vrsatile_models import ValueObjectDescriptor
-from pydantic import BaseModel, StrictBool, validator
+from ga4gh.vrsatile.pydantic.core_models import CURIE
+from ga4gh.vrsatile.pydantic.vrsatile_models import TherapeuticDescriptor
+from pydantic import BaseModel, StrictBool
 
 from therapy.version import __version__
 
@@ -393,15 +392,6 @@ class MatchesListed(BaseModel):
             }
 
 
-class TherapyDescriptor(ValueObjectDescriptor):
-    """Create therapy descriptor model"""
-
-    type: Literal["TherapyDescriptor"] = "TherapyDescriptor"
-    therapy_id: CURIE
-
-    _get_therapy_id_val = validator("therapy_id", allow_reuse=True)(return_value)
-
-
 class ServiceMeta(BaseModel):
     """Metadata regarding the therapy-normalization service."""
 
@@ -562,7 +552,7 @@ class UnmergedNormalizationService(BaseNormalizationService):
 class NormalizationService(BaseNormalizationService):
     """Response containing one or more merged records and source data."""
 
-    therapy_descriptor: Optional[TherapyDescriptor]
+    therapeutic_descriptor: Optional[TherapeuticDescriptor]
     source_meta_: Optional[Dict[SourceName, SourceMeta]]
 
     class Config:
@@ -580,10 +570,10 @@ class NormalizationService(BaseNormalizationService):
                 "query": "cisplatin",
                 "warnings": None,
                 "match_type": 80,
-                "therapy_descriptor": {
+                "therapeutic_descriptor": {
                     "id": "normalize.therapy:cisplatin",
-                    "type": "TherapyDescriptor",
-                    "therapy_id": "rxcui:2555",
+                    "type": "TherapeuticDescriptor",
+                    "therapeutic": "rxcui:2555",
                     "label": "cisplatin",
                     "xrefs": [
                         "ncit:C376", "chemidplus:15663-27-1",
